import { createContext, useState, useContext } from 'react';
import Repository from '../../repository/Repository';
import { useError } from './ErrorProvider';

const ActivationContext = createContext(null);

const ActivationProvider = ({children}) => {
  const [key, setKey] = useState("");
  const [isPhysicalKey, setIsPhysicalKey] = useState(false);
  const { setError, resetError } = useError();

  const validateKey = (value) => new Promise(resolve => {

    const data = {key: value};

    setKey(value);

    Repository.post("/key/validate/", data).then(resp => {
      if (resp.data) {
        setIsPhysicalKey(resp.data?.type === "Stripe - physical");
        resetError();
        try {
          const coordinates = resp.data.location.match(/(-?\d+\.\d+)\s(-?\d+\.\d+)/);
          resolve({
            coordinates: {
              lng: parseFloat(coordinates[1]),
              lat: parseFloat(coordinates[2]),
            },
            soilVariant: resp.data.soil_variant[0],
            zone: {id: resp.data.zone},
            ...data,
          });
        } catch {
          resolve({...data, ...resp.data});
        }
      } else {
        resolve(null);
      }
    }).catch(e => {
      switch (e.response.status) {
        case 400:
        case 404:
          setError("Invalid or expired activation key. Please try again.");
          break;
        default:
          setError("Something went wrong. Please try again.");
          break;
      }
      resolve(null);
    });
  });

  const value = {
    key,
    isDigitalKey: !isPhysicalKey,
    isPhysicalKey,
    validateKey,
  };

  return <ActivationContext.Provider value={value}>{children}</ActivationContext.Provider>;
};

const useActivator = () => useContext(ActivationContext);

export {
  ActivationProvider,
  useActivator,
};
