import { useState } from "react";
import Box from '@mui/material/Box';
import Button from '@mui/material/Button';
import Step from "../Step";
import LocationSelectorMap from "./Map";
import StepInformation from "../StepInformation";
import staticText from "../../../assets/data/staticText.json";
import locationBackgroundImage from "../../../assets/img/stepBackgrounds/step1.jpg";
import { StepperFooter } from '../../providers/StepperProvider';
import AddressSearch from "./AddressSearch";
import { useFilter } from '../../providers/FilterProvider';

export default function LocationStep({defaultIsSearch = false}) {
  const [nextDisabled, setNextDisabled] = useState(true);
  const [showSearch, setShowSearch] = useState(defaultIsSearch);
  const { updateFilters } = useFilter();

  const locationInfoPanel = (
    <div>
      <StepInformation
        title={staticText.steps.location.title}
        description={<p>{staticText.steps.location.description}</p>}
      />
      <Box sx={{ display: 'flex', flexDirection: 'row', py: 2, paddingRight: '10pt', paddingLeft: '10pt', minHeight: '68px' }}>
        <Box sx={{ flex: '1 1 auto' }} />
        <Button onClick={() => setShowSearch(s => !s)}>Switch to {showSearch ? "map" : "search"}</Button>
      </Box>
    </div>
  );

  const selectionComponent = showSearch
    ? <AddressSearch onSelect={address => {
      if (address) {
        setNextDisabled(false);
        updateFilters({
          coordinates: {
            lat: address.coordinates[1],
            lng: address.coordinates[0],
          },
        });
      } else {
        setNextDisabled(true);
      }
    }}/>
    : <LocationSelectorMap setNextDisabled={setNextDisabled} />;

  return (
    <>
      <Step
        informationComponent={locationInfoPanel}
        selectionComponent={selectionComponent}
        backgroundImage={locationBackgroundImage}
      />
      <StepperFooter nextDisabled={nextDisabled} />
    </>
  );
};
