import React from "react";
import ReactDOM from "react-dom";
import { createTheme, ThemeProvider } from "@mui/material/styles";
import reportWebVitals from "./reportWebVitals";
import { createBrowserRouter, RouterProvider } from "react-router-dom";
import MainPage from "./pages/MainPage";
import { FilterProvider } from "./components/providers/FilterProvider";

// Styles
import "./assets/styles/main.scss";
import "bootstrap/dist/css/bootstrap.min.css";
import { ActivationProvider } from "./components/providers/ActivationProvider";
import { ErrorProvider } from "./components/providers/ErrorProvider";

const router = createBrowserRouter([
  {
    path: "/",
    element: <MainPage />,
  },
]);

const darkTheme = createTheme({
  palette: {
    mode: "dark",
  },
  typography: {
    fontFamily: "Poppins, sans-serif",
  },
});

ReactDOM.render(
  <React.StrictMode>
    <div className="App">
      <ErrorProvider>
        <FilterProvider>
          <ActivationProvider>
            <ThemeProvider theme={darkTheme}>
              <RouterProvider router={router} />
            </ThemeProvider>
          </ActivationProvider>
        </FilterProvider>
      </ErrorProvider>
    </div>
  </React.StrictMode>,
  document.getElementById("root")
);

// If you want to start measuring performance in your app, pass a function
// to log results (for example: reportWebVitals(console.log))
// or send to an analytics endpoint. Learn more: https://bit.ly/CRA-vitals
reportWebVitals();
